import { TranslateService } from '@eo-sdk/core';
import { PendingChangesComponent } from './pending-changes-component.interface';
import { Observable } from 'rxjs';
import { Logger } from '@eo-sdk/core';
/**
 * EditingObserver service is used to track changes made inside the application, that should prevent
 * doing something or going somewhere before the changes are persisted or ignored. For example when
 * the user starts editing form data and tries to navigate away before saving the changes, this service
 * will take care of notifying the user.
 *
 * It is working kind of like a registry for ongoing tasks that need to be monitored. Every component
 * that needs to be aware of changes to be persisted can start a task and finish it when everything is done.
 *
 * Other components can ask the service for pending tasks to know whether or not to execute an action
 * (e.g. list component will subscribe and prevent selecting another list item, if changes to the previous one haven't be finished)
 *
 * app.component will prevent relevant route changes while tasks are pending.
 */
export declare class PendingChangesService {
    private logger;
    private translate;
    private tasks;
    private tasksSource;
    tasks$: Observable<string[]>;
    constructor(logger: Logger, translate: TranslateService);
    /**
     * Registers a task to be pending.
     * @returns Unique id to be used for finishing this task
     */
    startTask(): string;
    /**
     * Finishes a task
     * @param id The id of the task to be finished. This is the one the component got from startTask()
     */
    finishTask(id: string): void;
    /**
     * Returns whether or not the service has pending tasks.
     * If an id is provided, the method will check existence of one specific task.
     *
     * @param id The id of the task to be checked
     * @returns
     */
    hasPendingTask(id?: string): boolean;
    /**
     * Returns whether or not the component|service has pending tasks.
     * Checks via confirm dialog
     * @param component
     * @returns
     */
    check(component?: PendingChangesComponent): boolean;
    /**
     * Clear list of pending tasks
     */
    clear(): void;
}
