import { OrgGroup, OrgRole, OrgUser } from './org.model';
/**
 * Representation of a work item. Work items are the parts of a process (workflow).
 */
export declare class WorkItem {
    /**
     * unique identifier
     */
    id: string;
    /**
     * work items title
     */
    title: string;
    /**
     * work items description
     */
    description: string;
    /**
     * the state the work item is in e.g. 'PERSON', 'CREATED', etc.
     */
    state: string;
    /**
     * ID of the parent process
     */
    processId: string;
    /**
     * title of the parent process
     */
    processTitle: string;
    /**
     * subject of the parent process
     */
    processSubject: string;
    /**
     * Form model for this work item. May be empty if the work item does not require user inputs
     */
    form: any;
    /**
     * Data for the form model. Form definition and the forms data are separated, and will be merged by the application.
     */
    data: any;
    /**
     * Meta data for data properties. Some form elements require additional information about the actual value.
     * Such values are for example form elements of type CODESYSTEM or ORGANIZATION.
     */
    data_meta: any;
    /**
     * Work items may define actions aside from the default `continue` action. This property holds a collection of all
     * actions provided by the current work item.
     */
    actions: WorkItemAction[];
    /**
     * A work items file is a container that holds objects (e.g. DMS Objects) attached to the current work item. A work item for
     * approving an invoice for example would have the related invoice document attached.
     */
    file: FileEntry[];
    /**
     * Permissions for the work items file entries, that allow or deny adding or removing entries from the work items file.
     */
    fileEntryPermissions: {
        add: boolean;
        remove: boolean;
    };
    /**
     * Work items may be received by users in substitution for other users that are currently unavailable.
     * If this is the case this property holds the information about the user that should have retrieved the work item.
     */
    inSubstituteOf: OrgUser[];
    /**
     * Work items are able to be set up with an escalation property that defines a due date for the work item to have been processed.
     * Items that exceed this date may be handled in a different way (e.g. marked red inside the inbox to indicate the urgent state)
     */
    escalation: {
        name: string;
        startTime: Date;
        fireTime: Date;
    };
    /**
     * When set to true, executing an action requires additional authorization.
     */
    authRequired: boolean;
    /**
     * The date the work item has been received
     */
    received: Date;
    /**
     * Performers are users, groups and/or roles that received the work item
     */
    performer: {
        groups: OrgGroup[];
        roles: OrgRole[];
        users: OrgUser[];
    };
    /**
     * Creates a new instance
     * @param json The JSON object received from the backend. This will be used to construct the new work item instance
     */
    constructor(json: any);
    setFile(fileEntries: FileEntry[]): void;
}
/**
 * A work items action
 */
export interface WorkItemAction {
    /**
     * The actions title (label)
     */
    title: string;
    /**
     * Short description of the action
     */
    description?: string;
    /**
     * The actions type. Values may be `FORWARD` (forward to the next process step) or `LINK` (open an external link to e.g. process
     * or retrieve data required for the current work item)
     */
    type: string;
    /**
     * Code that identifies the action (kind of an ID in context of the current work item)
     */
    code: number;
    /**
     * If actions type is set to `LINK` this property holds the target URL to forward to
     */
    url?: string;
}
/**
 * Entry of a work items file
 */
export interface FileEntry {
    /**
     * unique identifier
     */
    id: string;
    /**
     * Title of the file entry
     */
    title: string;
    /**
     * Short description of the file entry
     */
    description: string;
    /**
     * ID of an icon (e.g. object type icon in case of dms objects)
     */
    iconid: string;
    /**
     * Name of the user that created this file entry
     */
    creator: string;
    /**
     * The time (date) this entry was added to the work item
     */
    addtime: number;
    /**
     * file entries type
     */
    type: string;
}
/**
 * @ignore
 */
export interface ExecutableProcess {
    id: string;
    title: string;
    description: string;
    iconid: string;
    data: any;
    qname: string;
    form: any;
    actions?: any;
}
