import { Observable } from 'rxjs';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Config } from '../config/config.service';
import { DmsObject } from '../../model/dms-object.model';
import { Logger } from '../logger/logger';
import { AuthProfile } from '../auth/auth-profile.interface';
import { HttpParams } from '@angular/common/http';
/**
 * `BackendService` encapsulates the communication with the enaio REST endpoints.
 *
 * As enaio provides different services, this service is also capable of providing the base URIs for those services.
 */
export declare class BackendService {
    private http;
    private logger;
    private config;
    private authProfile;
    private cache;
    private temp;
    private headers;
    /**
     * @ignore
     */
    constructor(http: HttpClient, logger: Logger, config: Config);
    /**
     * @ignore
     */
    setAuthProfile(profile?: AuthProfile): void;
    /**
     * Add a new header.
     * @param key The headers name
     * @param value The value
     */
    setHeader(key: string, value: string): void;
    /**
     * Retrieves the current headers
     * @returns The `HttpHeaders` that are currently set up
     */
    getHeaders(): HttpHeaders;
    /**
     * @ignore
     */
    getHttpOptions(requestOptions?: any): {
        headers?: HttpHeaders | {
            [header: string]: string | string[];
        };
        observe?: 'body';
        params?: HttpParams | {
            [param: string]: string | string[];
        };
        reportProgress?: boolean;
        responseType: 'arraybuffer';
        withCredentials?: boolean;
    };
    /**
     * Gets the base URI for the DMS-Service endpoint
     * @returns Base URI
     */
    getServiceBase(): string;
    /**
     * Gets the base URI for the Search-Service endpoint
     * @returns Base URI
     */
    getSearchBase(): string;
    /**
     * Gets the base URI for the Context-Service endpoint
     * @returns Base URI
     */
    getContextBase(): string;
    /**
     * Gets the base URI for the Inbox-Service endpoint
     * @returns Base URI
     */
    getInboxBase(): string;
    /**
     * Gets the base URI for the BPM-Service endpoint
     * @returns Base URI
     */
    getBpmBase(): string;
    /**
     * Gets the base URI for the Agent-Service endpoint
     * @returns Base URI
     */
    getAgentBase(): string;
    /**
     * @ignore
     */
    getIconBase(id?: string): string;
    /**
     * @ignore
     */
    getHost(): string;
    /**
     * Wrapped HTTP GET method
     * @param uri The REST URI to be queried
     * @param base The Base URI (backend service) to be used
     * @param requestOptions Additional request options
     * @returns The data retrieved from the given endpoint
     */
    get(uri: string, base?: string, requestOptions?: any): Observable<any>;
    /**
     * Wrapped HTTP PUT method
     * @param uri The target REST URI
     * @param data Data to be 'posted'
     * @param base The Base URI (backend service) to be used
     * @returns The return value of the target PUT endpoint
     */
    put(uri: string, data?: any, base?: string): Observable<any>;
    /**
     * @ignore
     */
    getJson(uri: string, base?: string): Observable<any>;
    /**
     * Wrapped HTTP POST method
     * @param uri The target REST URI
     * @param data Data to be 'posted'
     * @param base The Base URI (backend service) to be used
     * @param requestOptions Additional request options
     * @returns The return value of the target POST endpoint
     */
    post(uri: string, data?: any, base?: string, requestOptions?: any): Observable<any>;
    /**
     * Wrapped HTTP DELETE method
     * @param uri The target REST URI
     * @param base The Base URI (backend service) to be used
     * @param requestOptions Additional request options
     * @returns The return value of the target DELETE endpoint
     */
    del(uri: string, base?: string, requestOptions?: any): Observable<any>;
    /**
     * @ignore
     * Soft update for lists - enables grid to handle all changes
     * to add new - only item should be specified
     * to remove - only id should be specified
     * to update - both params should be specified
     *
     * @param any[] list Original list of items
     * @param id?: string; item?: any data[]
     * @returns any[]
     */
    update(list: any[], data: {
        id?: string;
        item?: any;
    }[]): any[];
    /**
     * @ignore
     * Cache for small requests like icons and configs
     *
     * @param string uri
     * @returns Observable<any>
     */
    getViaCache(uri: string): Observable<any>;
    /**
     * @ignore
     * Temporary Cache for multiple identical requests
     *
     * @param string id
     * @param Function request
     * @returns Observable<any>
     */
    getViaTempCache(id: string, request?: Function): Observable<any>;
    /**
     * Download the content of dms objects.
     *
     * @param DmsObject[] dmsObjects Array of dms objects to be downloaded
     * @param "PDF" | "TIFF" | "TEXT" | "JPEG" rendition The type of rendition to be downloaded. If not specified, the original content will be downloaded.
     * Possible renditions are `PDF`, `TIFF`, `TEXT`, `JPEG`.
     */
    downloadContent(dmsObjects: DmsObject[], rendition?: 'PDF' | 'TIFF' | 'TEXT' | 'JPEG'): void;
    private getFileNameFromHttpResponse(res, version);
    /**
     * Getter for the HTTP Headers
     *
     * @returns HttpHeaders
     */
    private setDefaultHeaders();
}
