import { Observable } from 'rxjs';
import { ExecutableProcess, WorkItem, WorkItemAction } from '../../model/work-item.model';
import { BackendService } from '../backend/backend.service';
import { WorkItemHistoryEntry } from '../../model/work-item-history.model';
import { DmsObject } from '../../model/dms-object.model';
import { InboxService } from '../inbox/inbox.service';
import { EventService } from '../events/event.service';
import { CapabilitiesService } from '../capabilities/capabilities.service';
import { CustomAction } from '../../model/custom-action.model';
/**
 * BpmService handles interaction related to BPM tasks.
 */
export declare class BpmService {
    private capabilities;
    private backend;
    private eventService;
    private inboxService;
    constructor(capabilities: CapabilitiesService, backend: BackendService, eventService: EventService, inboxService: InboxService);
    /**
     * Getter for the Executable Processes. If dms objects are provided, you'll get
     * only the processes that are executable for all of them
     * @param dmsObjects List of dms objects to fetch executable processes for
     * @returns List of executable processes
     */
    getExecutableProcesses(dmsObjects?: DmsObject[]): Observable<ExecutableProcess[]>;
    /**
     * Loader for the Executable Processes
     * @param dmsObjects List of dms objects to fetch executable processes for
     * @returns Observable<ExecutableProcess[]>
     */
    private fetchExecutableProcesses(dmsObjects?);
    /**
     * Create a Process Item ([WorkItem]{@link WorkItem})
     *
     * @param item
     * @param content
     * @returns WorkItem
     */
    private createProcessItem(item, content);
    /**
     * Getter for the Processes
     *
     * @param processId The ID of the process to be fetches
     */
    getProcess(processId: string): Observable<any>;
    /**
     * Retrieves a work item.
     *
     * @param processId ID of the parent process
     * @param itemId ID of the work item
     * @param options options to be added to the backend call
     * @returns Observable<WorkItem>
     */
    getWorkItem(processId: string, itemId: string, options?: any): Observable<WorkItem>;
    /**
     * Saves a work item.
     *
     * @param item The work item to be saved
     * @returns Observable<WorkItem>
     */
    saveWorkItem(item: WorkItem): Observable<WorkItem>;
    /**
     * Forwards a work item
     *
     * @param item The work item to be forwarded
     * @param action Action code
     * @returns Observable<any>
     */
    forwardWorkItem(item: WorkItem, action?: WorkItemAction): Observable<any>;
    /**
     * Locks a workitem for the current user (personalization).
     *
     * @param item The work item to be locked
     * @returns Observable<WorkItem>
     */
    lockWorkItem(item: WorkItem): Observable<WorkItem>;
    /**
     * Releases the lock for a work item.
     *
     * @param item The work item to be unlocked
     * @returns Observable<WorkItem>
     */
    unlockWorkItem(item: WorkItem): Observable<WorkItem>;
    /**
     * Getter for the Custom Actions
     *
     * @param DmsObject[] objTypes
     * @returns Observable<CustomAction[]>
     */
    getCustomActions(objTypes?: DmsObject[]): Observable<CustomAction[]>;
    /**
     * Create a new Process
     *
     * @param processDescriptor
     * @returns Observable<any>
     */
    createProcess(processDescriptor: any): Observable<any>;
    /**
     * Returns the history for a process. Which entries are returned depends on the
     * permissions of the current user.
     *
     * @param processId The ID of the process to fetch history for
     * @returns Observable<WorkItemHistoryEntry[]>
     */
    getProcessHistory(processId: string): Observable<WorkItemHistoryEntry[]>;
    /**
     * Removes a content from the work items file
     *
     * @param processId The ID of the process to remove the item from
     * @param workItemId The ID of the work item containing the file element to be removed
     * @param workItemContentId The the ID of the file element to be removed
     * @returns Observable<any>
     */
    removeFileElement(processId: string, workItemId: string, workItemContentId: string): Observable<any>;
    /**
     * Add contents to a work item.
     *
     * @param processId The ID of the process
     * @param workItemId The ID of the activity
     * @param elements The Elements to be added
     * @returns Observable<WorkItem> The updated WorkItem
     */
    addFileElements(processId: string, workItemId: string, elements: DmsObject[]): Observable<WorkItem>;
}
