import { Observable } from 'rxjs';
import { DmsObject, DmsObjectAttachment } from '../../model/dms-object.model';
import { BackendService } from '../backend/backend.service';
import { SystemService } from '../system/system.service';
import { DmsObjectHistoryEntry } from '../../model/dms-object-history.model';
import { EventService } from '../events/event.service';
import { DmsParams } from './dmsParams.interface';
/**
 * Collection of DMS Services
 */
export declare class DmsService {
    private backend;
    private systemService;
    private eventService;
    constructor(backend: BackendService, systemService: SystemService, eventService: EventService);
    /**
     * Fetches a dms object.
     *
     * @param id Objects id
     * @param type Objects type name, will improve load time if provided
     * @param version Target version
     * @param intent Used for server side logging. If you provide an intent, the backend will recognize the request and add it to its logs
     * @returns Observable<DmsObject>
     */
    getDmsObject(id: string, type?: string, version?: number, intent?: string): Observable<DmsObject>;
    /**
     * Getter for the DMS Objects by params
     *
     * @param DmsParams params
     * @returns Observable<DmsObject>
     */
    getDmsObjectByParams(params: DmsParams): Observable<DmsObject>;
    /**
     * Reolver of Object Types by DMS Object
     *
     * @param DmsObject dmsObject
     * @returns DmsObject
     */
    resolveObjectTypes(dmsObject: DmsObject): DmsObject;
    /**
     * Deletes a DMS object.
     * @param id The id of the dms object to be deleted.
     * @param type Type of object
     * @param hardDelete If object should really be deleted or only put into the recycle bin
     */
    deleteDmsObject(id: string, type?: string, hardDelete?: boolean): Observable<any>;
    /**
     * Returns the context path of the given dms object
     * @param id The id of the object.
     * @returns The context path of the dms object
     */
    getContextPath(id: string): Observable<any>;
    /**
     * Fetches the children of a DmsObject.
     *
     * @param dmsObject
     * @returns Observable<DmsObject[]>
     */
    getChildren(dmsObject: DmsObject): Observable<DmsObject[]>;
    /**
     * Fetches the versions of a DmsObject.
     *
     * @param id
     * @param type
     * @returns Observable<DmsObject>
     */
    getVersions(id: string, type?: string): Observable<DmsObject>;
    /**
     * Fetches the attachments of a DmsObject.
     *
     * @param dmsObject
     * @returns Observable<DmsObjectAttachment[]>
     */
    getAttachments(dmsObject: DmsObject): Observable<DmsObjectAttachment[]>;
    /**
     * Fetches the specific attachment of a DmsObject.
     *
     * @param id
     * @param index
     * @returns string
     */
    getAttachmentByIndex(id: string, index: number): string;
    /**
     * Generates the URI for getting a DmsObjects slide (Preview image).
     *
     * @param id Objects id
     * @param type Objects type name, will improve load time if provided
     * @param version Target version
     * @param size The size of the preview image in px
     * @returns string
     */
    getSlide(id: string, type?: string, version?: number, size?: number): string;
    /**
     * Generates the URI for getting a DmsObjects preview (PDF rendition).
     *
     * @param id Objects id
     * @param type] Objects type name, will improve load time if provided
     * @param version Target version
     * @returns string
     */
    getPreview(id: string, type?: string, version?: number): string;
    /**
     * Updates an existing dms object.
     *
     * @param id ID of the object to be updated
     * @param indexdata Object holding the objects indexdata (property: value)
     * @param type The object type of the object to be updated
     * @returns Observable<DmsObject> The updated dms object
     */
    updateObject(id: string, indexdata: any, type?: string): Observable<DmsObject>;
    /**
     * Fetch the history (audit) of one dms object
     *
     * @param id ID of the dms object to fetch history for
     * @param type Type of the dms object to fetch history for
     * @returns Observable<DmsObjectHistoryEntry[]> The history of the dms object
     */
    getHistory(id: string, type?: string): Observable<DmsObjectHistoryEntry[]>;
    /**
     * Restores an earlier version of the selected DmsObject by adding the earlier version
     * as the new recent version.
     *
     * @param id DMS object id
     * @param version The version to be restored
     * @param type The dms object type
     * @return
     */
    restoreVersion(id: string, version: number, type?: string): Observable<any>;
    /**
     * if dmsObject is specified, load latest version and trigger Enaio event DMS_OBJECT_UPDATED
     *
     * @param dmsObject
     * @param request
     * @return
     */
    triggerUpdate(dmsObject: DmsObject, request: Observable<any>): Observable<any>;
    /**
     * Remove Content
     *
     * @param DmsObject dmsObject
     * @returns Observable<any>
     */
    removeContent(dmsObject: DmsObject): Observable<any>;
    /**
     * Create a Subscription
     *
     * @param DmsObject dmsObject
     * @param string subject
     * @param receiver
     * @param boolean sendEmail
     * @param boolean onlyEmail
     * @returns Observable<any>
     */
    createSubscription(dmsObject: DmsObject, subject: string, receiver: any, sendEmail: boolean, onlyEmail: boolean): Observable<any>;
    /**
     * Create a Resubmission
     *
     * @param DmsObject dmsObject
     * @param string subject
     * @param due
     * @param receiver
     * @param boolean sendEmail
     * @param boolean onlyEmail
     * @returns Observable<any>
     */
    createResubmission(dmsObject: DmsObject, subject: string, due: any, receiver: any, sendEmail: boolean, onlyEmail: boolean): Observable<any>;
    /**
     * Reamove a Subscription by a given Id
     *
     * @param subscriptionId
     * @param DmsObject dmsObject
     * @returns Observable<any>
     */
    removeSubscriptionById(subscriptionId: any, dmsObject?: DmsObject): Observable<any>;
    /**
     * Remove a Resubmission by a given Id
     *
     * @param itemId
     * @param DmsObject dmsObject
     * @returns Observable<any>
     */
    removeResubmissionsById(itemId: any, dmsObject?: DmsObject): Observable<any>;
    /**
     * Update a Resubmission
     *
     * @param DmsObject dmsObject
     * @param string subject
     * @param due
     * @param receiver
     * @param boolean sendEmail
     * @param boolean onlyEmail
     * @returns Observable<any>
     */
    updateResubmission(dmsObject: DmsObject, subject: string, due: any, receiver: any, sendEmail: boolean, onlyEmail: boolean): Observable<any>;
    /**
     * Setter for Organization Objects With Read Rights
     *
     * @param DmsObject]} dmsObjects
     * @param string]} orgaNames
     * @returns Observable<any>
     */
    setOrganizationObjectsWithReadRights(dmsObjects: DmsObject[], orgaNames: string[]): Observable<any>;
    /**
     * Move a DMS Object
     *
     * @param id
     * @param typeName
     * @param parentId
     * @param parentTypeName
     * @returns Observable<any>
     */
    move(id: any, typeName: any, parentId: any, parentTypeName: any): Observable<any>;
    /**
     * Copy a DMS Object
     *
     * @param id
     * @param typeName
     * @param parentId
     * @param parentTypeName
     * @param createContentLink
     * @returns Observable<any>
     */
    copy(id: any, typeName: any, parentId: any, parentTypeName: any, createContentLink: any): Observable<any>;
    /**
     * Set a DMS Object to Finilited
     *
     * @param DmsObject item
     * @returns Observable<any>
     */
    finalize(item: DmsObject): Observable<any>;
    /**
     * Remove the Finilized Flag from a DMS Object
     *
     * @param DmsObject item
     * @returns Observable<any>
     */
    definalize(item: DmsObject): Observable<any>;
}
