import { BackendService } from '../backend/backend.service';
import { Observable } from 'rxjs';
import { ObjectType } from '../../model/object-type.model';
import { PreparedItem, PreparedItemTemplate } from '../../model/prepared-item.model';
import { UploadService } from '../upload/upload.service';
import { UploadTarget } from '../../model/upload-target.model';
import { UploadFileItem } from '../../model/upload-file-item.model';
import { IPrepareChildTypes } from './objectTypes.interface';
/**
 * @ignore
 */
export interface PreparedPostParam {
    parentId: string;
    /**
     * flag indicating whether or not to create one PreparedItem using multiple files uploaded (false)
     * or creating a PreparedItem for each file posted to the URL (true)
     */
    createMany?: boolean;
    childType?: string;
}
/**
 * Collection of Prepare Services
 */
export declare class PrepareService {
    private backend;
    private uploadService;
    private preparedItems;
    private preparedItemsSource;
    preparedItems$: Observable<PreparedItem[]>;
    private preparedItemCount;
    private preparedItemCountSource;
    preparedItemCount$: Observable<number>;
    constructor(backend: BackendService, uploadService: UploadService);
    /**
     * Public Fetch Prepare items
     */
    refreshPreparedItemsCount(): void;
    /**
     * Fetches the number of prepared items for the current user.
     */
    private fetchPreparedItemsCount();
    /**
     * Creates a prepared item on the backed side.
     *
     * @param parentId The ID of the parent dms object to add the prepared item to
     * @param childType The type of object to be created
     * @returns Observable<any>
     */
    createPreparedItem(parentId: string, childType?: string): Observable<any>;
    /**
     *
     * @param preparedItemId
     * @param data
     * @returns Observable<any>
     */
    updatePreparedItemIndexData(preparedItemId: any, data: any): Observable<any>;
    /**
     * Creates an URL for creating a PreparedItem.
     *
     * @param params Params for generating appropriate uri.
     * @returns string A POST URL for creating PreparedItems
     */
    createPreparedItemPostUrl(params: PreparedPostParam): string;
    /**
     * Retrieves a list of the users prepared items.
     *
     * @param noForms If set to true the prepared items will be fetched without the form which is faster
     * @returns Observable<PreparedItem[]> A collection of prepared item objects
     */
    getPreparedItems$(noForms?: boolean): Observable<PreparedItem[]>;
    /**
     * Retrieve PrepareItems and form them
     *
     * @param boolean noForms
     * @returns Observable<PreparedItem[]>
     */
    private fetchPreparedItems(noForms?);
    /**
     * Removes a prepared item.
     *
     * @param preparedItemId ID of the item to be removed
     * @returns Observable<any> Server response
     */
    deletePreparedItem(preparedItemId: string): Observable<any>;
    /**
     * Fetches a list of object types allowed to be placed directly below root.
     *
     * @returns Observable<ObjectType[]> A list of supported object types
     */
    getPrepareRootTypes(): Observable<ObjectType[]>;
    /**
     * Fetches a list of allowed child object types for a selected parent.
     *
     * @param parentId The id of the parent dms object (context folder)
     * @param withContentOnly If set to true only child types, that support content are returned.
     * @returns Observable<IPrepareChildTypes> A list of supported object types
     */
    getPrepareChildTypes(parentId: string, withContentOnly?: boolean): Observable<IPrepareChildTypes>;
    /**
     * fetch the preview uri for a prepared item
     *
     * @param id The id of the prepared item
     * @param index When a prepared item contains more than one contents, the index specifies which content
     * to retrieve the preview uri for
     * @returns string Preview uri
     */
    getPreviewUri(id: string, index?: number): string;
    /**
     * Updates the prepared items target object type.
     *
     * @param objectType The target object types name
     * @param preparedItemId The id of the prepared item to set the type for
     * @returns Observable<PreparedItem> The updated prepared item
     */
    updateChildType(objectType: string, preparedItemId: string): Observable<PreparedItem>;
    /**
     * Add a template to a prepared item.
     *
     * @param preparedItemId The id of the prepared item to add the template to
     * @param templateId The id of the template to be added
     * @returns Observable<PreparedItem>  The updated prepared item
     */
    addTemplate(preparedItemId: any, templateId: any): Observable<PreparedItem>;
    /**
     * Fetches a list of available templates for a given object type.
     *
     * @param Observable<PreparedItemTemplate[]> objectTypeName
     */
    getTemplates(objectTypeName: string): Observable<PreparedItemTemplate[]>;
    /**
     * Returns url of a templates preview
     *
     * @param id Templates ID
     * @returns string The templates preview url.
     */
    getTemplatePreviewUri(id: any): string;
    /**
     * Commit a prepared item. This will create an actual dms object.
     * Updates the prepared creation object target type
     *
     * @param preparedItemId ID of the prepared item
     * @param preparedItemType Name of the prepared items target object type
     * @param preparedItemData Object holding data of the prepared item
     * @returns The id of the created dms object
     */
    commitPreparedItem(preparedItemId: any, preparedItemType: any, preparedItemData: any): Observable<any>;
    /**
     * Upload Content
     *
     * @param string preparedItemId
     * @param File file
     * @returns Observable<any>
     */
    uploadContent(preparedItemId: string, file: File): Observable<any>;
    /**
     * Uploads files to an upload target.
     *
     * @param uploadTarget The upload target to upload files to
     * @param uploadFiles Files to be uploaded
     * @param useBatchUpload Flag indicating whether or not to use batch processing on the backend side
     * @returns Observable<any>
     */
    uploadToTarget(uploadTarget: UploadTarget, uploadFiles: UploadFileItem[], useBatchUpload?: boolean): Observable<any>;
    /**
     * Get the uri to post files to based on the upload target.
     *
     * @param uploadTarget The target to upload files to
     * @param useBatchUpload Flag indicating whether or not to upload all files in a single post
     * @returns string the uri
     */
    private getUploadTarget(uploadTarget, useBatchUpload?);
}
