import { ObjectType } from '../../model/object-type.model';
/**
 * The SearchQuery Class
 *
 * See {@link SearchService} for Usage
 */
export declare class SearchQuery {
    /**
     * Base Parameters for a Search Query
     */
    static BASE_PARAMS: {
        TYPE: string;
        CREATOR: string;
        CREATED: string;
        MODIFIER: string;
        MODIFIED: string;
        FILESIZE: string;
        FILENAME: string;
        MIMETYPEGROUP: string;
    };
    /**
     * Time period buckets property names
     */
    static TIME_PERIOD_BUCKETS: {
        TODAY: string;
        YESTERDAY: string;
        THIS_WEEK: string;
        LAST_WEEK: string;
        THIS_MONTH: string;
        LAST_MONTH: string;
        THIS_YEAR: string;
        LAST_YEAR: string;
    };
    /**
     * mimetype buckets property names
     */
    static MIMETYPEGROUP_BUCKETS: {
        PDF: string;
        MAIL: string;
        WORD: string;
        IMAGE: string;
        OCTET_STREAM: string;
        TXT: string;
        EXCEL: string;
        POWERPOINT: string;
        VIDEO: string;
        HTML: string;
    };
    /**
     * filesize buckets property names
     */
    static FILE_SIZE_BUCKETS: {
        LT1MB: string;
        LT10MB: string;
        LT100MB: string;
        GT100MB: string;
    };
    /**
     * Detault Search mode Index
     */
    static DEFAULT_SEARCH_MODE: string;
    /**
     * Search mode for Full test Search
     */
    static FULLTEXT_SEARCH_MODE: string;
    /**
     * fulltext search term
     */
    term: string;
    /**
     * Array of fields to request from the search service, leaving this blank will return the fields specified in the result field configuration
     */
    fields: string[];
    /**
     * List of object types to be fetched by the query. Leaving this blank will return results from any type
     */
    types: ObjectType[];
    /**
     * List of context folder types
     */
    contextFolderTypes: ObjectType[];
    /**
     * List of filters to define the query
     */
    filters: SearchFilter[];
    /**
     * Whether or not to retrieve suggestions
     */
    suggest: boolean;
    /**
     * Whether or not the term is an expert mode query
     */
    expertMode: boolean;
    /**
     * The search mode to be used (SearchQuery.DEFAULT_SEARCH_MODE or SearchQuery.FULLTEXT_SEARCH_MODE)
     */
    searchMode: string;
    /**
     * Additional options to be applied to the query
     */
    sortOptions: SortOption[];
    /**
     * The state of the current query
     */
    state: SearchState;
    constructor();
    /**
     * Adds a new target type to the query
     *
     * @param type Object type to be added
     */
    addType(type: ObjectType): void;
    /**
     * Removes a type from the target types list
     *
     * @param type The object type to be removed
     */
    removeType(type: ObjectType): void;
    /**
     * Adds or removes the given type based on the current settings
     *
     * @param type The object type to be toggled
     */
    toggleType(type: ObjectType): void;
    /**
     * Adds a new filter to the query. If there already is a filter set for the given property, it will be overridden.
     *
     * @param filter The filter to be added
     */
    addFilter(filter: SearchFilter): void;
    /**
     * Removes a filter from the query.
     *
     * @param filterPropertyName The filter (its property name) to be removed
     */
    removeFilter(filterPropertyName: string): void;
    /**
     * Adds or removes the given filter based on the current settings
     *
     * @param filter The filter to be toggled
     */
    toggleFilter(filter: SearchFilter, override?: boolean): void;
    /**
     * Retrieves a filter by its property name.
     *
     * @param propertyName The filters property name (qname of form element)
     * @returns Search Filter Object
     */
    getFilter(propertyName: string): SearchFilter;
    /**
     * Adding new Sort Options
     * Sort Options are only added if they are not already present
     *
     * @param name
     * @param order
     * @param missing
     */
    addSortOption(name: string, order: string, missing?: string): void;
    /**
     *
     * @param name
     */
    removeSortOption(name: string): void;
    /**
     * Generate a query JSON from the current SearchQuery that can be send to the search service.
     */
    getQueryJson(): any;
    private applyOptions();
}
/**
 * @ignore
 * Creates the Model of Sort Options
 */
export declare class SortOption {
    field: string;
    order: string;
    missing: string;
    constructor(field: string, order: string, missing?: string);
}
/**
 * @ignore
 * Creates the Model of Field Definitions
 */
export declare class FieldDefinition {
    elements: any[];
    sortorder: any[];
    grouporder: any[];
    pinned: any[];
    mode: string;
    constructor(elements?: any[], sortorder?: any[], grouporder?: any[], pinned?: any[], mode?: string);
}
/**
 * @ignore
 * Class representing the state of a query
 */
export declare class SearchState {
    count: number;
    aggregations: any;
    lastChange?: string;
    /**
     * @ignore
     */
    constructor();
    addAggregations(type: string, key: string, value: number, agg?: any): void;
}
/**
 * @ignore
 * Creates the Model of Search Results
 */
export declare class SearchResult {
    count: number;
    suggests: string[];
    hits: any[];
    fields: FieldDefinition;
    constructor();
}
export declare class SearchFilter {
    property: string;
    operator: string;
    firstValue: any;
    secondValue: any;
    /**
     * available operators for a search filter
     */
    static OPERATOR: {
        EQUAL: string;
        IN: string;
        GREATER_THAN: string;
        GREATER_OR_EQUAL: string;
        LESS_THAN: string;
        LESS_OR_EQUAL: string;
        INTERVAL: string;
        INTERVAL_INCLUDE_BOTH: string;
        INTERVAL_INCLUDE_TO: string;
        INTERVAL_INCLUDE_FROM: string;
        RANGE: string;
    };
    /**
     * Constructor for creating a new SearchFilter.
     *
     * @param property The qualified name of the field this filter should apply to.
     * @param operator Operator indicating how to handle the filters value(s). See SearchFilter.OPERATOR for available operators.
     * @param firstValue The filters value
     * @param secondValue Optional second value for filters that for example define ranges of values
     */
    constructor(property: string, operator: string, firstValue: any, secondValue?: any);
    /**
     * @ignore
     */
    match(property: string, operator: string, firstValue: any, secondValue?: any): boolean;
}
