import { Observable } from 'rxjs';
import { FieldDefinition, SearchFilter, SearchQuery, SearchResult, SearchState } from './search-query.model';
import { BackendService } from '../backend/backend.service';
import { SystemService } from '../system/system.service';
import { Config } from '../config/config.service';
import { ObjectType } from '../../model/object-type.model';
import { RangeValue } from '../../model/range-value.model';
/**
 * Collection of Search Services
 * See {@link SearchQuery} for Query Definition
 */
export declare class SearchService {
    private system;
    private backend;
    private config;
    constructor(system: SystemService, backend: BackendService, config: Config);
    /**
     * Creates a RangeValue instance from the given value object.
     *
     * @param value The object to be
     * @returns RangeValue
     */
    static toRangeValue(value: any): RangeValue;
    /**
     * Creates a fromated search Query
     *
     * @param query
     * @returns SearchQuery
     */
    buildQuery(query: any): SearchQuery;
    /**
     * Executes a query.
     *
     * @param query The query to be executed
     * @returns Observable<SearchResult>
     */
    search(query: SearchQuery): Observable<SearchResult>;
    /**
     * Retrieve Search results
     *
     * @param SearchQuery query
     * @returns Observable<SearchState>
     */
    getSearchState(query: SearchQuery): Observable<SearchState>;
    /**
     * Fetches a part of a queries result. This can be used for paging of results
     * or lazy loading large results.
     *
     * @param query The query to be executed
     * @param fromIndex The index from where to fetch results
     * @param chunkSize Size of the chunk to be fetched
     * @returns Observable<SearchResult>
     */
    getChunkedResult(query: SearchQuery, fromIndex: number, chunkSize: number): Observable<SearchResult>;
    /**
     * Executes a query
     *
     * @param queryJson The query JSON to be executed
     * @param aggregateSearch Flag indicating whether or not to execute an aggregation search (no actual results)
     * @param customSize Custom number of results to be fetched, if not set the default size will be applied
     * @returns Observable<any>
     */
    executeQuery(queryJson: object, aggregateSearch?: boolean, customSize?: number): Observable<any>;
    /**
     * Executes a search for fetching suggestions on a given search term.
     *
     * @param term The search term
     * @return
     */
    autocomplete(term: string): Observable<any>;
    /**
     * Use this method to create a SearchFilter for a form element. Based on the target types
     * it'll create the right kind of filter that you then can add to a SearchQuery
     *
     * @param targetTypes
     * @param formElementName
     * @param elementValue
     * @returns SearchFilter[] An array of search filters most of the time containing only one entry, but
     * for table elements this could be more
     */
    getSearchFilter(targetTypes: ObjectType[], formElementName: string, elementValue: any): SearchFilter[];
    /**
     * identifies form elements that are enabled to contain multiple values
     * try to find the form element inside of the provided object types to get its type
     *
     * @param ObjectType[] targetTypes
     * @param string formElementName
     * @return SearchFilterType
     */
    private identifySearchFilter(targetTypes, formElementName);
    /**
     * identifies form elements that are enabled to contain multiple values
     *
     * @param formElement
     * @return boolean
     */
    private isMultiselectSearchFilter(formElement);
    /**
     * Creates a QueryResult from the response sent by the server
     *
     * @param backendResponse Server response
     * @returnThe SearchResult SearchQuery object created from the server response
     */
    createResultFromResponse(backendResponse: any): SearchResult;
    /**
     * Provides the Resul tField Definition Config
     *
     * @param SearchQuery query
     * @return ({type: ObjectType; contextType: ObjectType})
     */
    getResultFieldDefinitionConfig(query: SearchQuery): {
        type: ObjectType;
        contextType: ObjectType;
    };
    private resolveConfigTypeNames(type, contextType);
    /**
     * Fetches the result field definition for a given object type
     * USER: (default) the result list configuration saved by the current user
     * DEFAULT: the default result list configuration (also returned when there is no user configuration)
     * ALL: all available result fields for the given type (and context)
     *
     * @param ObjectType | null type The object type
     * @param ObjectType | null contextType Object type target types allowed context type
     * @param mode The result lists configuration mode:
     * @return Observable<FieldDefinition>
     */
    fetchResultFieldDefinition(type: ObjectType | null, contextType: ObjectType | null, mode: any): Observable<FieldDefinition>;
    /**
     * Saves a column definition as result or common result.
     *
     * @param ObjectType | null type The object type
     * @param ObjectType | null contextType Object type target types allowed context type
     * @param FieldDefinition data The result list configuration to be persisted
     * @param boolean common Flag enables to set config as default / common result
     * @return Observable<any>
     */
    saveResultFieldDefinition(type: ObjectType | null, contextType: ObjectType | null, data: FieldDefinition, common?: boolean): Observable<any>;
    /**
     * Removes a column definition.
     *
     * @param ObjectType | null type The object type
     * @param ObjectType | null contextType Object type target types allowed context type
     * @return Observable<any>
     */
    removeResultFieldDefinition(type: ObjectType | null, contextType: ObjectType | null): Observable<any>;
}
