import { Observable } from 'rxjs';
import { BackendService } from '../backend/backend.service';
import { SystemService } from '../system/system.service';
import { StoredQueriesSubscription } from './stored-queries-subscription.interface';
import { StoredQuery } from './stored-query.model';
import { SearchService } from '../search/search.service';
import { SearchFilter } from '../search/search-query.model';
import { EventService } from '../events/event.service';
/**
 * Service managing stored queries.
 * To use it just call `getStoredQueries$` which will return the current
 * state of the list of stored queries. This one is a long term observable, so bare in mind
 * to unsubscribe from it when you don't need it any more (or your component gets destroyed).
 *
 * Every change to the list of stored queries is done using this service. So don't change the
 * retrieved list locally inside of your component. Otherwise other components that subscribe
 * to the stored query list will not be notified.
 */
export declare class StoredQueriesService {
    private backend;
    private system;
    private searchService;
    private eventService;
    /**
     * Temporary ID for new stored queries
     */
    static ID_NEW: string;
    /**
     * qname of fulltext params
     */
    static FULLTEXT: string;
    private storedQueries;
    private storedQueriesSource;
    /**
     * Stream of stored queries
     */
    storedQueries$: Observable<StoredQueriesSubscription>;
    /**
     * @ignore
     */
    constructor(backend: BackendService, system: SystemService, searchService: SearchService, eventService: EventService);
    /**
     * Clear list of stored queries.
     */
    clear(): void;
    /**
     * Provides you with a `long term observable` holding the stored queries.
     */
    getStoredQueries$(): Observable<StoredQueriesSubscription>;
    /**
     * Will re-fetch the data from the backend. This will propagate a
     * new value to your subscription.
     */
    refreshStoredQueries(): void;
    /**
     * Fetches the stored queries from the backend and propagates a new
     * value to the main subject.
     */
    private fetchStoredQueries();
    /**
     * Save new Stored Query
     *
     * @param StoredQuery storedQuery
     * @return Observable<StoredQuery>
     */
    private saveNewStoredQuery(storedQuery);
    /**
     * Update Stored Query
     *
     * @param StoredQuery storedQuery
     * @return Observable<StoredQuery>
     */
    private updateStoredQuery(storedQuery);
    /**
     * Save a stored query. Depending on whether or not the provided query is a new one or not
     * this will either update or create a new query.
     *
     * @param storedQuery Stored query to be saved
     */
    saveStoredQuery(storedQuery: StoredQuery): Observable<StoredQuery>;
    /**
     * Remove Stored Query be provided ID
     * @param id ID of the stored query to be removed
     */
    removeStoredQuery(id: string): Observable<any>;
    /**
     * Gets the value to be added to a form element by extracting it from a
     * search filter. The kind of value differs based on the form elements type.
     *
     * @param filter The filter to extract value from
     * @param formElementType Form elements type ('STRING', 'DATE', 'CODESYSTEM', ...)
     * @returns the extracted value
     */
    filterToElementValue(filter: SearchFilter, formElementType: string): any;
    /**
     * Creates a pseudo form element for a stored queries fulltext input field
     * to be used inside of a stored query form.
     *
     * @param label The label to be set to the element
     * @param value A value to be set to the element
     */
    getFulltextFormElement(label: string, value: string): {
        name: string;
        qname: string;
        label: string;
        value: string;
        type: string;
    };
}
