import { SearchQuery } from '../search/search-query.model';
/**
 * @ignore
 * Interface for the data used for backend communication.
 * This is the kind of data we'll get from the server and we
 * have to provide when sending stored queries to the server.
 */
export interface IStoredQuery {
    id: string;
    name: string;
    query: string;
    favorite?: boolean;
    shared?: boolean;
    user?: string;
    version?: number;
    roles?: string[];
    parameter?: string[];
}
/**
 * @ignore
 * Interface for dynamic parameter properties.
 * Form elements will be transformed to this format to save only
 * required properties
 */
export interface IStoredQueryParam {
    qname: string;
    type: string;
}
/**
 * Stored query is an extension of a SearchQuery. It adds properties like
 * name and a list of dynamic filter properties and the ability to generate
 * an object from its properties that could be pwersisted on the backend side.
 */
export declare class StoredQuery extends SearchQuery {
    /**
     * temporary id for new stored queries
     */
    static ID_NEW: string;
    id: string;
    name: string;
    favorite: boolean;
    shared: boolean;
    /**
     * the username of the user that created this query
     */
    user: string;
    version: number;
    roles: string[];
    parameter: IStoredQueryParam[];
    readonly title: string;
    constructor(item?: IStoredQuery);
    /**
     * Adds the properties of a SearchQuery to the current StoredQuery instance.
     * This is used when loading stored queries from the search service and when you
     * want to create a StoredQuery from a SearchQuery.
     * skip `fields` and `sortOptions` properties as they make no sense for stored queries
     *
     * @param searchQuery The search query to copy properties from
     */
    setQuery(searchQuery: SearchQuery): void;
    /**
     * Convert IStoredQueryParam objects to array of strings
     *
     * @returns IStoredQuery
     */
    toPersistableStoredQuery(): IStoredQuery;
    /**
     * Check if Query is new or allready Stored
     *
     * @returns boolean
     */
    isNew(): boolean;
}
