import { Observable } from 'rxjs';
import { IOrganizationObjects } from '../../interface/organization-objects.interface';
import { BackendService } from '../backend/backend.service';
import { AppCacheService } from '../cache/app-cache.service';
import { Logger } from '../logger/logger';
import { ObjectType } from '../../model/object-type.model';
import { EoUser } from '../../model/eo-user.model';
import { OrgRole } from '../../model/org.model';
import { ICodeSystem } from './systemdefinition.interface';
/**
 * Collection of System Services
 */
export declare class SystemService {
    private backend;
    private logger;
    private appCache;
    private system;
    private systemSource;
    system$: Observable<any>;
    private objectTypeForms;
    private user;
    private cachedRoles;
    constructor(backend: BackendService, logger: Logger, appCache: AppCacheService);
    /**
     * Gets all ObjectTypes
     *
     * @returns An array containing all object types
     */
    getObjectTypes(): ObjectType[];
    /**
     * Gets an ObjectType by name.
     *
     * @param objectTypeName The name of the object type
     * @returns the ObjectType matching the given name
     */
    getObjectType(objectTypeName: string): ObjectType;
    /**
     * Gets a codesystem
     *
     * @param id The codesystems id
     * @returns The codesystem object matching the given id
     */
    getCodesystem(id: string): ICodeSystem;
    /**
     * Get the form model of an object type.
     *
     * @param objectTypeName The object type name
     * @param situation The form situation to be fetched
     * @param mode Form mode to fetch (e.g. CONTEXT)
     * @returns The object type form model
     */
    getObjectTypeForm(objectTypeName: string, situation: string, mode?: string): Observable<any>;
    /**
     * Fetches the backends system definition and updates system$ Observable.
     * Subscribe to the system$ observable instead of calling this function, otherwise you'll trigger fetching the
     * system definition every time.
     *
     * @param user The user to load the system definition for
     * @returns true when successfull
     */
    getSystemDefinition(user: EoUser): Observable<boolean>;
    /**
     * Creates a value depending on a given Type
     *
     * @param string valueType
     * @returns any
     */
    getDefaultValue(valueType: string): any;
    /**
     * Fetches the system definition from the server. Provided params are used for storing the
     * recent version in cache.
     *
     * @param user The user to fetch the system definition for
     * @return boolean
     */
    fetchSystemDefinition(user: EoUser): Observable<boolean>;
    /**
     * Retrieve an organization object by its ID
     * @param id ID of org object
     */
    getOrganizationObjectById(id: string): Observable<any>;
    /**
     * Fetches the organization object for a given name.
     *
     * @param name The name to fetch object for
     * @returns
     */
    getOrganizationObject(name: string): Observable<any>;
    /**
     * Fetches a collection of organization objects
     *
     * @param names Array of names to fetch objects for
     * @returns A Array of Organization Objects
     */
    getOrganizationObjects(names: string[]): Observable<IOrganizationObjects[]>;
    /**
     * Fetches a collection of organization roles
     *
     * @return A Array of Organization Roles
     */
    getRoles(): Observable<OrgRole[]>;
}
