import { Observable } from 'rxjs';
import { TranslateService } from '@ngx-translate/core';
import { ChangePasswordInterface } from '../../interface/change-password.interface';
import { BackendService } from '../backend/backend.service';
import { EoUser } from '../../model/eo-user.model';
import { Config } from '../config/config.service';
import { Logger } from '../logger/logger';
import { SystemService } from '../system/system.service';
import { EventService } from '../events/event.service';
/**
 * Applications user service.
 * To get the current user you have to subscribe to the services `user$` observable.
 *
 * ```javascript
 * userService.user$.subscribe((user) => this.user = user);
 * ```
 *
 * This way your component will be provided with an up-to-date user object no matter
 * which component changes on of the users properties.
 */
export declare class UserService {
    private backend;
    private translate;
    private logger;
    private eventService;
    private system;
    private config;
    USER_FETCH_URI: string;
    private user;
    private userSource;
    /**
     * Observable emitting the current user
     */
    user$: Observable<any>;
    private favorites;
    private favoritesSource;
    /**
     * Observable emitting current users favorites
     */
    favorites$: Observable<any>;
    private notifications;
    private notificationsSource;
    /**
     * Observable emitting current users notifications
     */
    notifications$: Observable<any>;
    /**
     * @ignore
     */
    constructor(backend: BackendService, translate: TranslateService, logger: Logger, eventService: EventService, system: SystemService, config: Config);
    /**
     * Gets the current user.
     * @returns The current user or NULL if no user is logged in
     */
    getCurrentUser(): EoUser;
    /**
     * Set presence of the current user
     * @param present Value to set the users presence to
     */
    setPresence(present: boolean): Observable<any>;
    /**
     * Sets the deputies for the current user
     * @param deputiesNames Names of the users to be set as deputies
     */
    setDeputies(deputiesNames: string[]): Observable<any>;
    /**
     * Change the users client locale
     * @param iso ISO locale string to be set as new client locale
     */
    changeClientLocale(iso: string): void;
    /**
     * Change the users schema locale
     * @param iso ISO locale string to be set as new schema locale
     */
    changeSchemaLocale(iso: string): Observable<any>;
    /**
     * Set a new current user
     * @param user The user to be set as current user
     */
    setCurrentUser(user: EoUser): void;
    /**
     * Fetches the current users favorites
     */
    getFavorites(): Observable<any>;
    /**
     * Soft update for the users favorites
     * @param id ID of the favorite to be updated
     * @param item The new favorite item
     * @param multi Whether or not to update multiple items
     */
    updateFavorites(id?: string, item?: any, multi?: any[]): void;
    /**
     * Gets the users notifications (resubmissions and subscriptions)
     * @returns Resolved by list of the users notifications
     */
    getNotifications(): Observable<any>;
    /**
     * Gets the users resubmissions
     * @returns Collection of users resubmissions
     */
    getResubmission(): Observable<any>;
    /**
     * Gets the users subscriptions
     * @returns Collection of users subscriptions
     */
    getSubscription(): Observable<any>;
    /**
     * Removes a notification
     * @param id ID of the notification to be removed
     * @param type The notifications type ('SUBSCRIPTION', 'RESUBMISSION')
     */
    removeNotifications(id: string, type: string): Observable<any>;
    /**
     * Soft update for users notifications
     */
    updateNotifications(id?: string, item?: any, multi?: any[]): void;
    /**
     * Gets the URI to a users avatar image
     * @param userId The users ID
     * @returns URI to the user image
     */
    getUserImageUri(userId: string): string;
    /**
     * Removes a favorite item
     * @param favoriteId ID of the favorite item to be removed
     */
    removeFavorite(favoriteId: string): Observable<any>;
    /**
     * Create a new favorite item for the current user
     * @param id ID of the dms object to be set up as favorite
     * @param type The object type of the dms object
     * @param title The favorites title
     */
    createFavorite(id: string, type: string, title: string): Observable<any>;
    /**
     * @ignore
     */
    removeFavoritesForTarget(id: string): Observable<any>;
    /**
     * Changes the users preferred lock mode and persists it on the server
     * @param lock The value to set the lock settings to
     */
    changeLockSetting(lock: string): Observable<void>;
    /**
     * Changes the users password and persists it on the server
     */
    changePassword(payload: ChangePasswordInterface): Observable<any>;
    /**
     * Fetches the settings for the current user and stores the new User object on the session
     */
    private refreshCurrentUser();
}
